<?php

namespace Drupal\perspective\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * PerspectiveForm class.
 */
class PerspectiveForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'perspective_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // Form constructor.
    $form = parent::buildForm($form, $form_state);
    // Default settings.
    $config = $this->config('perspective.settings');

    $form['google_api_key'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Google API Key:'),
      '#default_value' => $config->get('perspective.google_api_key'),
      '#description' => $this->t('Get your api key here: https://console.cloud.google.com/apis/dashboard.'),
    );

    $form['tolerance'] = array(
      '#type' => 'number',
      '#title' => $this->t('Toxocity tolerance:'),
      '#default_value' => $config->get('perspective.tolerance'),
      '#description' => $this->t('From 0 to 100 (non-toxic to toxic).'),
    );

    $form['error_text'] = array(
      '#type' => 'textfield',
      '#title' => $this->t('Error text:'),
      '#default_value' => $config->get('perspective.error_text'),
      '#description' => $this->t('The error that will show up when the message fails the validation.'),
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('perspective.settings');
    $config->set('perspective.google_api_key', $form_state->getValue('google_api_key'));
    $config->set('perspective.tolerance', $form_state->getValue('tolerance'));
    $config->set('perspective.error_text', $form_state->getValue('error_text'));
    $config->save();

    return parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    // This function returns the name of the settings files we will
    // create / use.
    return [
      'perspective.settings',
    ];
  }

}
